xlapjrt

package module
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 28, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

README

XLA-PJRT Backend for GX

Use the excellent gopjrt to provide a GX backend using the PJRT runtime of the openxla project.

Disclaimer

This is not an official Google DeepMind product (experimental or otherwise), it is just code that happens to be owned by Google-DeepMind. GX is experimental and work in progress. As of today, we do not consider any part of the language as stable. Breaking changes will happen on a regular basis.

You are welcome to send PR or to report bugs. We will do our best to answer but there is no guarantee that you will get a response.

Documentation

Overview

Package xlapjrt provides a gopjrt backend to GX.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToDType

func ToDType(k dtype.DataType) dtypes.DType

ToDType converts a GX kind into a gopjrt DType.

func ToGXDType

func ToGXDType(k dtypes.DType) dtype.DataType

ToGXDType converts a gopjrt DType to a GX datatype.

func ToGXShape

func ToGXShape(sh xlabuilder.Shape) *shape.Shape

ToGXShape converts a gopjrt shape into a GX shape.

func ToShape

func ToShape(shape *shape.Shape) xlabuilder.Shape

ToShape converts a GX shape into a gopjrt/xla shape.

Types

type Supported

type Supported interface {
	dtype.GoDataType
	dtypes.Supported
}

Supported are the types supported by this backend.

Directories

Path Synopsis
Package backend provides a XLA backend to GX given a gomlx XLA client.
Package backend provides a XLA backend to GX given a gomlx XLA client.
graph
Package graph builds a PJRT graph.
Package graph builds a PJRT graph.
platform
Package platform provides the pjrt platform for GX.
Package platform provides the pjrt platform for GX.
Package cgx provides CGX access to the XLA-PJRT backend.
Package cgx provides CGX access to the XLA-PJRT backend.
Package gx encapsulates GX source files into a Go package.
Package gx encapsulates GX source files into a Go package.
Package plugin creates a PJRT GX backend from a PJRT plugin name.
Package plugin creates a PJRT GX backend from a PJRT plugin name.
Package stdlib provides the GX standard library for the PJRT (gopjrt) backend.
Package stdlib provides the GX standard library for the PJRT (gopjrt) backend.
Package testing provide a cgx runtime for GX testing.
Package testing provide a cgx runtime for GX testing.

Jump to